pitchtools.apply_octavation_spanner_to_pitched_components
=========================================================

.. autofunction:: abjad.tools.pitchtools.apply_octavation_spanner_to_pitched_components.apply_octavation_spanner_to_pitched_components
